summaryrefslogtreecommitdiffstats
path: root/ksysv/ksvmiscconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/ksvmiscconfig.cpp')
-rw-r--r--ksysv/ksvmiscconfig.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksysv/ksvmiscconfig.cpp b/ksysv/ksvmiscconfig.cpp
index 69b596a..d894262 100644
--- a/ksysv/ksvmiscconfig.cpp
+++ b/ksysv/ksvmiscconfig.cpp
@@ -31,11 +31,11 @@
#include <kdialog.h>
/*
* Constructs a KSVMiscConfig which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/
-KSVMiscConfig::KSVMiscConfig( TQWidget* tqparent, const char* name, WFlags fl )
- : MiscConfiguration( tqparent, name, fl )
+KSVMiscConfig::KSVMiscConfig( TQWidget* parent, const char* name, WFlags fl )
+ : MiscConfiguration( parent, name, fl )
{
mSpacer->setFixedHeight (KDialog::spacingHint());
@@ -31,11 +31,11 @@
#include <kdialog.h>
/*
- * Constructs a KSVMiscConfig which is a child of 'tqparent', with the
+ * Constructs a KSVMiscConfig which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/